@@ -6,11 +6,21 @@ from typing import Any, Generator, AsyncGenerator
 import pytest
 from fastapi import FastAPI
 from httpx import AsyncClient
+import uuid
+from unittest.mock import Mock
+
 {%- if cookiecutter.enable_redis == "True" %}
 from fakeredis.aioredis import FakeRedis
 from {{cookiecutter.project_name}}.services.redis.dependency import get_redis_connection
 {%- endif %}
+{%- if cookiecutter.enable_rmq == "True" %}
+from aio_pika import Channel
+from aio_pika.abc import AbstractExchange, AbstractQueue
+from aio_pika.pool import Pool
+from {{cookiecutter.project_name}}.services.rabbit.dependencies import get_rmq_channel_pool
+from {{cookiecutter.project_name}}.services.rabbit.lifetime import init_rabbit, shutdown_rabbit
 
+{%- endif %}
 from {{cookiecutter.project_name}}.settings import settings
 from {{cookiecutter.project_name}}.web.application import get_app
 
@@ -36,7 +46,13 @@ from psycopg import AsyncConnection
 from psycopg_pool import AsyncConnectionPool
 
 from {{cookiecutter.project_name}}.db.dependencies import get_db_session
+{%- elif cookiecutter.orm == "piccolo" %}
+{%- if cookiecutter.db_info.name == "postgresql" %}
+from piccolo.engine.postgres import PostgresEngine
+{%- endif %}
+from piccolo.table import create_tables, drop_tables
 
+from piccolo.conf.apps import Finder
 {%- endif %}
 
 
@@ -245,8 +261,146 @@ async def dbsession() -> AsyncGenerator[AsyncConnection[Any], None]:
         await pool.close()
         await drop_db()
 
+{%- elif cookiecutter.orm == "piccolo" %}
+
+{%- if cookiecutter.db_info.name == "postgresql" %}
+async def drop_database(engine: PostgresEngine) -> None:
+    """
+    Drops test database.
+
+    :param engine: engine connected to postgres database.
+    """
+    await engine.run_ddl(
+        "SELECT pg_terminate_backend(pg_stat_activity.pid) "  # noqa: S608
+        "FROM pg_stat_activity "
+        f"WHERE pg_stat_activity.datname = '{settings.db_base}' "
+        "AND pid <> pg_backend_pid();",
+    )
+    await engine.run_ddl(
+        f"DROP DATABASE {settings.db_base};",
+    )
 {%- endif %}
 
+@pytest.fixture(autouse=True)
+async def setup_db() -> AsyncGenerator[None, None]:
+    """
+    Fixture to create all tables before test and drop them after.
+
+    :yield: nothing.
+    """
+    {%- if cookiecutter.db_info.name == "postgresql" %}
+    engine = PostgresEngine(
+        config={
+            "database": "postgres",
+            "user": settings.db_user,
+            "password": settings.db_pass,
+            "host": settings.db_host,
+            "port": settings.db_port,
+        },
+    )
+    await engine.start_connection_pool()
+
+    db_exists = await engine.run_ddl(
+        f"SELECT 1 FROM pg_database WHERE datname='{settings.db_base}'"  # noqa: S608
+    )
+    if db_exists:
+        await drop_database(engine)
+    await engine.run_ddl(f"CREATE DATABASE {settings.db_base}")
+    {%- endif %}
+    tables = Finder().get_table_classes()
+    create_tables(*tables, if_not_exists=True)
+
+    yield
+
+    drop_tables(*tables)
+    {%- if cookiecutter.db_info.name == "postgresql" %}
+    await drop_database(engine)
+    {%- endif %}
+
+{%- endif %}
+
+{%- if cookiecutter.enable_rmq == 'True' %}
+
+@pytest.fixture
+async def test_rmq_pool() -> AsyncGenerator[Channel, None]:
+    """
+    Create rabbitMQ pool.
+
+    :yield: channel pool.
+    """
+    app_mock = Mock()
+    init_rabbit(app_mock)
+    yield app_mock.state.rmq_channel_pool
+    await shutdown_rabbit(app_mock)
+
+
+@pytest.fixture
+async def test_exchange_name() -> str:
+    """
+    Name of an exchange to use in tests.
+
+    :return: name of an exchange.
+    """
+    return uuid.uuid4().hex
+
+
+@pytest.fixture
+async def test_routing_key() -> str:
+    """
+    Name of routing key to use whild binding test queue.
+
+    :return: key string.
+    """
+    return uuid.uuid4().hex
+
+
+@pytest.fixture
+async def test_exchange(
+    test_exchange_name: str,
+    test_rmq_pool: Pool[Channel],
+) -> AsyncGenerator[AbstractExchange, None]:
+    """
+    Creates test exchange.
+
+    :param test_exchange_name: name of an exchange to create.
+    :param test_rmq_pool: channel pool for rabbitmq.
+    :yield: created exchange.
+    """
+    async with test_rmq_pool.acquire() as conn:
+        exchange = await conn.declare_exchange(
+            name=test_exchange_name,
+            auto_delete=True,
+        )
+        yield exchange
+
+        await exchange.delete(if_unused=False)
+
+
+@pytest.fixture
+async def test_queue(
+    test_exchange: AbstractExchange,
+    test_rmq_pool: Pool[Channel],
+    test_routing_key: str,
+) -> AsyncGenerator[AbstractQueue, None]:
+    """
+    Creates queue connected to exchange.
+
+    :param test_exchange: exchange to bind queue to.
+    :param test_rmq_pool: channel pool for rabbitmq.
+    :param test_routing_key: routing key to use while binding.
+    :yield: queue binded to test exchange.
+    """
+    async with test_rmq_pool.acquire() as conn:
+        queue = await conn.declare_queue(name=uuid.uuid4().hex)
+        await queue.bind(
+            exchange=test_exchange,
+            routing_key=test_routing_key,
+        )
+        yield queue
+
+        await queue.delete(if_unused=False, if_empty=False)
+
+{%- endif %}
 
 {% if cookiecutter.enable_redis == "True" -%}
 @pytest.fixture
@@ -272,6 +426,9 @@ def fastapi_app(
     {% if cookiecutter.enable_redis == "True" -%}
     fake_redis: FakeRedis,
     {%- endif %}
+    {%- if cookiecutter.enable_rmq == 'True' %}
+    test_rmq_pool: Pool[Channel],
+    {%- endif %}
 ) -> FastAPI:
     """
     Fixture for creating FastAPI app.
@@ -285,7 +442,9 @@ def fastapi_app(
     {%- if cookiecutter.enable_redis == "True" %}
     application.dependency_overrides[get_redis_connection] = lambda: fake_redis
     {%- endif %}
-
+    {%- if cookiecutter.enable_rmq == 'True' %}
+    application.dependency_overrides[get_rmq_channel_pool] = lambda: test_rmq_pool
+    {%- endif %}
     return application  # noqa: WPS331
 
 
